@@ -23,9 +23,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 __author__ = 'Alexandre Norman (norman at xael.org)'
-__version__ = '0.3.9'
-__last_modification__ = '2015.01.30'
-
+__version__ = '0.3.12'
+__last_modification__ = '2015.03.21'
 
 import copy
 import datetime
@@ -51,6 +50,9 @@ except ImportError:
     print("This program uses Orgnode. See : http://members.optusnet.com.au/~charles57/GTD/orgnode.html")
     sys.exit(1)
 
+
+import gantt
+
 ############################################################################
 
 def __show_version__(name, **kwargs):
@@ -159,7 +161,17 @@ def make_task_from_node(n, prop={}, prev_task=''):
     if n.deadline != '':
         end = "{0}".format(_iso_date_to_datetime(str(n.deadline)))
     if 'Effort' in n.properties:
-        duration = n.properties['Effort'].replace('d', '')
+        if 'w' in n.properties['Effort']:
+            # convert duration from week to days
+            nbweeks = int(n.properties['Effort'].replace('w', ''))
+            # how much days in one normal week ?
+            len_week = 7 - len(gantt.NOT_WORKED_DAYS)
+            duration = nbweeks * len_week
+        elif 'd' in n.properties['Effort']:
+            duration = n.properties['Effort'].replace('d', '')
+        else:
+            __LOG__.warning('no known unit for duration ({0} / {1})'.format(fullname, n.properties['Effort']))
+            duration = n.properties['Effort']
 
     if 'BLOCKER' in n.properties and n.properties['BLOCKER'].strip() == 'previous-sibling':
         depends_of = ['task_{0}'.format(prev_task)]
@@ -213,6 +225,8 @@ def make_task_from_node(n, prop={}, prev_task=''):
             ress = None
         except TypeError:
             ress = None
+        except AttributeError:
+            ress = None
 
 
     # get color from task properties
@@ -243,6 +257,7 @@ def make_task_from_node(n, prop={}, prev_task=''):
 @clize.clize(
     alias = {
         'debug': ('d',),
+        'warning': ('w',),
         'gantt': ('g',),
         'svg': ('S',),
         'resource': ('r',),
@@ -260,7 +275,7 @@ def make_task_from_node(n, prop={}, prev_task=''):
             ),
         )
     )
-def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, resource=False, svg='project', filter='', availibility=''):
+def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, resource=False, svg='project', filter='', availibility='', warning=False):
     """
     org2gantt.py
     
@@ -274,9 +289,9 @@ def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, r
 
     availibility: check resource availibility between start_date and end_date
 
-    start_date: force start date for output or used for checking resource availibility (format : 'yyyy-mm-dd')
+    start_date: force start date for output or used for checking resource availibility (format : 'yyyy-mm-dd' or '-1w' (from today))
 
-    end_date: force end date for output or used for checking resource availibility (format : 'yyyy-mm-dd')
+    end_date: force end date for output or used for checking resource availibility (format : 'yyyy-mm-dd' or '+2d' (from today))
 
     today: force today date (format : 'yyyy-mm-dd')
 
@@ -284,6 +299,8 @@ def __main__(org, gantt='', start_date='', end_date='', today='', debug=False, r
     
     debug: debug
 
+    warning: set warning level for creating gantt
+
     Example :
     python org2gantt.py TEST.org
 
@@ -300,10 +317,13 @@ import gantt
     global __LOG__
     if debug:
         _init_log_to_sysout(logging.DEBUG)
-        gantt_code += "\nimport logging\ngantt.init_log_to_sysout(logging.DEBUG)\n"
-
+        gantt_code += "\nimport logging\ngantt.init_log_to_sysout(level=logging.DEBUG)\n"
+    elif warning:
+        _init_log_to_sysout(logging.WARNING)
+        gantt_code += "\nimport logging\ngantt.init_log_to_sysout(level=logging.WARNING)"
     else:
         _init_log_to_sysout()
+        gantt_code += "\nimport logging\ngantt.init_log_to_sysout(level=logging.CRITICAL)"
 
     if not os.path.isfile(org):
         __LOG__.error('** File do not exist : {0}'.format(org))
@@ -370,8 +390,23 @@ import gantt
                 my_today = datetime.date(int(y), int(m), int(d))
 
         if start_date != '':
-            y, m, d = start_date.split('-')
-            planning_start_date = _iso_date_to_datetime(start_date)
+            dates = re.findall('[1-9][0-9]{3}-[0-9]{2}-[0-9]{2}', start_date)
+            if len(dates) == 1:
+                y, m, d = start_date.split('-')
+                planning_start_date = _iso_date_to_datetime(start_date)
+            elif start_date.startswith('-') or start_date.startswith('+'):
+                sign = start_date[0]
+                qte = int(start_date[1:-1])
+                what = start_date[-1]
+
+                sign = -1*(sign=='-') + 1*(sign=='+')
+                if what == 'd':
+                    planning_start_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(days=qte*sign)))
+                elif what == 'w':
+                    planning_start_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(weeks=qte*sign)))
+                else:
+                    __LOG__.critical('Unknown start date format : "{0}". Valid format are yyyy-mm-dd or [-+]x[dw]'.format(start_date))
+                    sys.exit(-1)
 
         elif 'start_date' in n_configuration.properties:
             # find date and use it
@@ -389,11 +424,30 @@ import gantt
                     planning_start_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(days=qte*sign)))
                 elif what == 'w':
                     planning_start_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(weeks=qte*sign)))
+                else:
+                    __LOG__.critical('Unknown start date format : "{0}". Valid format are yyyy-mm-dd or [-+]x[dw]'.format(start_date))
+                    sys.exit(-1)
 
 
         if end_date != '':
-            y, m, d = end_date.split('-')
-            planning_end_date = _iso_date_to_datetime(end_date)
+            dates = re.findall('[1-9][0-9]{3}-[0-9]{2}-[0-9]{2}', end_date)
+            if len(dates) == 1:
+                y, m, d = end_date.split('-')
+                planning_end_date = _iso_date_to_datetime(end_date)
+            # find +1m
+            elif end_date.startswith('-') or end_date.startswith('+'):
+                sign = end_date[0]
+                qte = int(end_date[1:-1])
+                what = end_date[-1]
+
+                sign = -1*(sign=='-') + 1*(sign=='+')
+                if what == 'd':
+                    planning_end_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(days=qte*sign)))
+                elif what == 'w':                                 
+                    planning_end_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(weeks=qte*sign)))
+                else:
+                    __LOG__.critical('Unknown end date format : "{0}". Valid format are yyyy-mm-dd or [-+]x[dw]'.format(end_date))
+                    sys.exit(-1)
 
         elif 'end_date' in n_configuration.properties:
             # find date and use it
@@ -411,10 +465,14 @@ import gantt
                     planning_end_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(days=qte*sign)))
                 elif what == 'w':                                 
                     planning_end_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(weeks=qte*sign)))
-                elif what == 'm':                                 
-                    planning_end_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(month=qte*sign)))
-                elif what == 'y':                                 
-                    planning_end_date = _iso_date_to_datetime(str(my_today + datetime.timedelta(years=qte*sign)))
+                else:
+                    __LOG__.critical('Unknown end date format : "{0}". Valid format are yyyy-mm-dd or [-+]x[dw]'.format(end_date))
+                    sys.exit(-1)
+
+
+    if planning_end_date <= planning_start_date:
+        __LOG__.critical('planning_end_date [{0}] is before planning_start_date [{1}]...'.format(planning_end_date, planning_start_date))
+        sys.exit(-1)
 
 
     __LOG__.debug('List of ignored tags : {0}'.format(LISTE_IGNORE_TAGS))
